# Python Valorant Wrapper
A Valorant wrapper written in Python, built to be used on a local machine

<a href="https://pypi.org/project/valorant-wrapper/"><img src="https://img.shields.io/pypi/v/valorant-wrapper?color=4c1"></a>
<a href="https://pypi.org/project/valorant-wrapper/"><img title="Weekly download count" alt="Weekly download count" src="https://img.shields.io/pypi/dw/valorant-wrapper?color=4c1"></a>
<a href="https://pypi.org/project/valorant-wrapper/"><img title="Total download count" alt="Total download count" src="https://static.pepy.tech/badge/valorant-wrapper"></a>
<a href="https://trello.com/b/kEz9g2VK/valorant-wrapper"><img src="https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Ftrello.com%2Fb%2FkEz9g2VK%2Fvalorant-wrapper.json&query=%24.cards.length&suffix=%20cards&logo=Trello&logoColor=white&label=Trello"></a>
<img src="https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fvalorant-api.com%2Fv1%2Fversion&query=%24.data.riotClientVersion&logo=Valorant&logoColor=white&label=Valorant%20Version">
<a href="https://github.com/Whitelisted1/Valorant-Python-Wrapper/stargazers"><img src="https://img.shields.io/github/stars/whitelisted1/Valorant-Python-Wrapper"></a>

## Resources used
* https://github.com/techchrism/valorant-api-docs
* https://github.com/zayKenyon/VALORANT-rank-yoinker as a reference

## Legal
This project is not affiliated with Riot Games or any of its employees and therefore does not reflect the views of said parties.

Riot Games does not endorse or sponsor this project. Riot Games, and all associated properties are trademarks or registered trademarks of Riot Games, Inc.